strut_length = 780;
num_braces = 0;
front_plate = true;
bottom_plate = true;
dogbones = 3.5;
front_wing_size = 8;

render_2d = false;

if (render_2d) {
  plates_2d();
}
else {
  rx(90)
  linear_extrude(height=1)
  plates_2d();
}


module plates_2d() {
  if (front_plate) {
    strut_plate(strut_length, num_braces, 0, front_wing_size);
  }
  if (bottom_plate) {
    ty(-95) strut_plate(strut_length, num_braces, 1, 5.5);
  }
}

module strut_plate(xlen, nbraces_=0, bot=0, extra=8.5) {
  margin = 0.25;
  nbraces = nbraces_ ? nbraces_ : floor((xlen-18)/(165+18)) + 1;
  // ceil(xlen / 200) + 1;
  space_between = ((xlen-18)/(nbraces-1))-18;
  echo("space between braces: ", space_between);
  echo("(center-to-center distance is 18mm more than that.)");
  
  nspaces = nbraces-1;
  pitch = (xlen-18)/nspaces;
  difference() {
    union() {
      // main rectangle
      tx(0.25) square([xlen-0.5, 67.5]);
      
      // extensions
      for (i=[0:nbraces-2])
      tx(18+margin+i*pitch) ty(-extra) square([pitch-18-2*margin, 67.5+2*extra]);
    }
    
    // holes
    ty([5.75, 67.5-5.75]) tx([for (i=[0:nbraces-1]) i*pitch + 9]) 
    circle(d=5.3, $fn=36);
    
    // other features
    if (bot == 0) {
      ty(30.49) square([5.25, 12]);
      
      // right side large notch
      tx(xlen-35.25) ty(10.85) square([35, 19.1]);
    }
    
    if (dogbones > 0) {
      for (i=[0:nbraces-2])
        tx(18+margin+i*pitch) {
          rz(45) tx(-dogbones/2) circle(d=dogbones, $fn=30);
          ty(67.5) rz(-45) tx(-dogbones/2) circle(d=dogbones, $fn=30);
          
          tx(pitch-18-2*margin) {
            rz(-45) tx(dogbones/2) circle(d=dogbones, $fn=30);
            ty(67.5) rz(45) tx(dogbones/2) circle(d=dogbones, $fn=30);
          }
        }
    }
  }
}

module tq(q, v)
  if (is_list(q)) for (qq=q) tq(qq, v) children();
  else translate(q*v) children();

module tx(q) tq(q, [1, 0, 0]) children();
module ty(q) tq(q, [0, 1, 0]) children();
module tz(q) tq(q, [0, 0, 1]) children();

module rq(q, v)
  if (is_list(q)) for (qq=q) rq(qq, v) children();
  else rotate(q*v) children();

module rx(q) rq(q, [1, 0, 0]) children();
module ry(q) rq(q, [0, 1, 0]) children();
module rz(q) rq(q, [0, 0, 1]) children();